@@ -48,6 +48,8 @@
 
 #include <libexslt/exslt.h>
 
+#define NETCF_TRANSACTION "/bin/false"
+
 static const char *const network_interfaces_path =
     "/files/etc/network/interfaces";
 
@@ -1042,7 +1044,7 @@ const char *drv_mac_string(struct netcf_if *nif) {
  */
 
 int drv_if_up(struct netcf_if *nif) {
-    static const char *const ifup = "ifup";
+    static const char *const ifup = IFUP;
     struct netcf *ncf = nif->ncf;
     int result = -1;
 
@@ -1054,7 +1056,7 @@ int drv_if_up(struct netcf_if *nif) {
 }
 
 int drv_if_down(struct netcf_if *nif) {
-    static const char *const ifdown = "ifdown";
+    static const char *const ifdown = IFDOWN;
     struct netcf *ncf = nif->ncf;
     int result = -1;
 
