@@ -1,7 +1,7 @@
 /*
  * dutil_linux.c: Linux utility functions for driver backends.
  *
- * Copyright (C) 2009, 2011 Red Hat Inc.
+ * Copyright (C) 2009, 2011, 2012 Red Hat Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -54,14 +54,50 @@
 #include "dutil.h"
 #include "dutil_linux.h"
 
+#ifndef HAVE_LIBNL3
 #include <net/if.h>
+#endif
 #include <netlink/socket.h>
 #include <netlink/cache.h>
 #include <netlink/route/addr.h>
 #include <netlink/route/link.h>
 
-/* For some reason, the headers for libnl vlan functions aren't installed */
+#ifdef HAVE_LIBNL3
+#define RTNL_LINK_NOT_FOUND 0
+
+/* Some distributions seem to never have shipped the vlan header with libnl1 */
+#include <netlink/route/link/vlan.h>
+#else
 extern int rtnl_link_vlan_get_id(struct rtnl_link *link);
+#endif
+
+static struct nl_cache *__rtnl_link_alloc_cache(struct nl_sock *sk)
+{
+    struct nl_cache *cache;
+
+#ifdef HAVE_LIBNL3
+    if (rtnl_link_alloc_cache(sk, AF_UNSPEC, &cache) < 0)
+        return NULL;
+#elif HAVE_LIBNL
+    cache = rtnl_link_alloc_cache(sk);
+#endif
+
+    return cache;
+}
+
+static struct nl_cache *__rtnl_addr_alloc_cache(struct nl_sock *sk)
+{
+    struct nl_cache *cache;
+
+#ifdef HAVE_LIBNL3
+    if (rtnl_addr_alloc_cache(sk, &cache) < 0)
+        return NULL;
+#elif HAVE_LIBNL
+    cache = rtnl_addr_alloc_cache(sk);
+#endif
+
+    return cache;
+}
 
 /*
  * Executing external programs
@@ -796,23 +832,20 @@ done:
 
 int netlink_init(struct netcf *ncf) {
 
-    ncf->driver->nl_sock = nl_handle_alloc();
+    ncf->driver->nl_sock = nl_socket_alloc();
     if (ncf->driver->nl_sock == NULL)
         goto error;
-    if (nl_connect(ncf->driver->nl_sock, NETLINK_ROUTE) < 0) {
+    if (nl_connect(ncf->driver->nl_sock, NETLINK_ROUTE) < 0)
         goto error;
-    }
 
-    ncf->driver->link_cache = rtnl_link_alloc_cache(ncf->driver->nl_sock);
-    if (ncf->driver->link_cache == NULL) {
+    ncf->driver->link_cache = __rtnl_link_alloc_cache(ncf->driver->nl_sock);
+    if (ncf->driver->link_cache == NULL)
         goto error;
-    }
     nl_cache_mngt_provide(ncf->driver->link_cache);
 
-    ncf->driver->addr_cache = rtnl_addr_alloc_cache(ncf->driver->nl_sock);
-    if (ncf->driver->addr_cache == NULL) {
+    ncf->driver->addr_cache = __rtnl_addr_alloc_cache(ncf->driver->nl_sock);
+    if (ncf->driver->addr_cache == NULL)
         goto error;
-    }
     nl_cache_mngt_provide(ncf->driver->addr_cache);
 
     int netlink_fd = nl_socket_get_fd(ncf->driver->nl_sock);
@@ -837,7 +870,7 @@ int netlink_close(struct netcf *ncf) {
     }
     if (ncf->driver->nl_sock) {
         nl_close(ncf->driver->nl_sock);
-        nl_handle_destroy(ncf->driver->nl_sock);
+        nl_socket_free(ncf->driver->nl_sock);
         ncf->driver->nl_sock = NULL;
     }
     return 0;
@@ -1041,7 +1074,7 @@ static void add_vlan_info_cb(struct nl_object *obj, void *arg) {
     if (cb_data->vlan != NULL)
         return;
 
-    link_type = rtnl_link_get_info_type(iflink);
+    link_type = rtnl_link_get_type(iflink);
     if ((link_type == NULL) || STRNEQ(link_type, "vlan"))
         return;
 
